@@ -92,6 +92,7 @@ class GQLHandler:
 
     async def login_a(self):
         data = (await self.runGqlQuery_a(gm.MUTATION["tokenM"], self.variables))['data']
+        print(data)
         if data['issueToken'] == None:
             # Login failed.
             raise LoginError("Login to Xplora® API failed. Check your input!")
@@ -133,7 +134,6 @@ class GQLHandler:
 ########## SECTION QUERY start ##########
 
     async def getMyInfo_a(self): # Profil from login Account
-        await self.login_a()
         return (await self.runAuthorizedGqlQuery_a(gq.QUERY['readMyInfoQ'], {}))['data']
 
     async def getContacts_a(self, ownId): # Contacts from ownUser
